package mixi
{
	import mx.effects.Move;
	import flash.display.DisplayObject;
	import mx.effects.Fade;
	import mx.events.EffectEvent;
	import mx.effects.Resize;
	import mx.controls.Alert;
	import mx.effects.Sequence;
	import flash.events.EventDispatcher;
	import flash.events.Event;
	
	public class ProfCarier extends EventDispatcher
	{
		private var window: MixiSoukanzu;
		private var mixiClient: MixiClient;

		public function ProfCarier(window:MixiSoukanzu, mixiClient:MixiClient):void
		{
			this.window     = window;
			this.mixiClient = mixiClient;
		}
		
		public function play(ctrl:ProfForm):void
		{
			var status:ProfCarierStatus = new ProfCarierStatus();
			
			// まずターゲットを移動するので複製する
			var target:ProfForm = new ProfForm();
			target.visible = false;
			
			// 操作対象オブジェクトに設定
			status.target = target;
			
			// とりあえず重ねて表示
			window.addChild(target);

			target.x = ctrl.x;
			target.y = ctrl.y;
			target.width = ctrl.width;
			target.height = ctrl.height;
			target.photo.load(ctrl.photo.source);
			target.userName.label = ctrl.userName.label;
			target.visible = true;
			target.alpha   = 1;

			// バッチ処理の順序を記述
			status.operations = [
				hideObjects,
				move,
				resize,
				copyToMe,
				showObjects,
				destruct
			];

			// 最初の処理を実行			
			status.doNext();
			
		}
		
		// 拡大処理
		private function resize(status:ProfCarierStatus):void
		{
			// 拡大部分の設定
			var resize:Resize = new Resize;
			resize.widthTo  = window.profMe.width;
			resize.heightTo = window.profMe.height;
			resize.duration = 300;
			resize.addEventListener(
				EffectEvent.EFFECT_END,
				function(e:EffectEvent):void{
					// 次の処理
					status.doNext();
				}
			);
			
			resize.play([status.target]);
		}

		private function move(status:ProfCarierStatus):void
		{
			var seq:Sequence = new Sequence;
			
			// 移動部分の設定
			var move:Move = new Move();
			move.xFrom = status.target.x;
			move.yFrom = status.target.y;

			move.xTo   = window.profMe.x;
			move.yTo   = window.profMe.y;
			move.duration = 5000;
			
			move.addEventListener(
				EffectEvent.EFFECT_END,
				function(e:EffectEvent):void{
					// 次の処理
					status.doNext();
				}
			);

			move.play([status.target]);
		}
		
		// 全部のオブジェクトを隠す処理
		private function hideObjects(status:ProfCarierStatus):void
		{
			var targets:Array = new Array();
			
			targets.push(window.profMe);
			for(var i:int = 0; i < 8; ++i) {
				targets.push(
					window.getChildByName("prof" + (i+1)),
					window.getChildByName("relation" + (i+1))
				);
			}
			
			var fade:Fade = new Fade()
			fade.alphaFrom = 1;
			fade.alphaTo   = 0;
			fade.duration  = 1000;
			fade.addEventListener(
				EffectEvent.EFFECT_END,
				function(e:EffectEvent):void{
					for each(var obj:DisplayObject in targets) {
						obj.visible = false;
					}
					// 次の処理を実行
					status.doNext();
				}
			);

			fade.play(targets);
		}

		// 全部のオブジェクトを表示する処理
		private function showObjects(status:ProfCarierStatus):void
		{
			var targets:Array = new Array();

			targets.push(window.profMe);
//			for(var i:int = 0; i < 8; ++i) {
//				targets.push(
//					window.getChildByName("prof" + (i+1)),
//					window.getChildByName("relation" + (i+1))
//				);
//			}

			for each(var obj:DisplayObject in targets) {
				obj.visible = true;
			}
			
			var fade:Fade = new Fade()
			fade.alphaFrom = 0;
			fade.alphaTo   = 1;
			fade.duration  = 1000;
			fade.addEventListener(
				EffectEvent.EFFECT_END,
				function(e:EffectEvent):void{
					// 次の処理
					status.doNext();
				}
			);

			fade.play(targets);
		}
		
		private function copyToMe(status:ProfCarierStatus):void
		{
			// ターゲットから自分へコピーする
			var target:ProfForm = status.target;
			var ctrl:ProfForm = window.profMe;
			ctrl.photo.load(target.photo.source);
			ctrl.userName.label = target.userName.label;
			
			// 次の処理を実行
			status.doNext();
		}
		
		private function destruct(status:ProfCarierStatus):void
		{
			status.target.visible = false;
			window.removeChild(status.target);
			
			// 多分最後だとは思うけど・・・
			status.doNext();
			
			// 終了通知
			dispatchEvent(new Event(Event.COMPLETE));
		}
	}
}